@@ -1,5 +1,6 @@
 package Net::Amazon::S3::Client;
-$Net::Amazon::S3::Client::VERSION = '0.94';
+# ABSTRACT: An easy-to-use Amazon S3 client
+$Net::Amazon::S3::Client::VERSION = '0.95';
 use Moose 0.85;
 use HTTP::Status qw(status_message);
 use MooseX::StrictConstructor 0.16;
@@ -7,22 +8,27 @@ use Moose::Util::TypeConstraints;
 
 use Net::Amazon::S3::Error::Handler::Confess;
 
-# ABSTRACT: An easy-to-use Amazon S3 client
-
 type 'Etag' => where { $_ =~ /^[a-z0-9]{32}(?:-\d+)?$/ };
 
-has 's3' => ( is => 'ro', isa => 'Net::Amazon::S3', required => 1 );
+has 's3' => (
+	is => 'ro',
+	isa => 'Net::Amazon::S3',
+	required => 1,
+	handles => [
+		'ua',
+	],
+);
 
 has error_handler_class => (
-    is => 'ro',
-    lazy => 1,
-    default => 'Net::Amazon::S3::Error::Handler::Confess',
+	is => 'ro',
+	lazy => 1,
+	default => 'Net::Amazon::S3::Error::Handler::Confess',
 );
 
 has error_handler => (
-    is => 'ro',
-    lazy => 1,
-    default => sub { $_[0]->error_handler_class->new (s3 => $_[0]->s3) },
+	is => 'ro',
+	lazy => 1,
+	default => sub { $_[0]->error_handler_class->new (s3 => $_[0]->s3) },
 );
 
 around BUILDARGS => sub {
@@ -47,21 +53,21 @@ __PACKAGE__->meta->make_immutable;
 sub bucket_class { 'Net::Amazon::S3::Client::Bucket' }
 
 sub buckets {
-    my $self = shift;
-    my $s3   = $self->s3;
+	my $self = shift;
+	my $s3   = $self->s3;
 
-    my $response = $self->_perform_operation (
-        'Net::Amazon::S3::Operation::Buckets::List',
-    );
+	my $response = $self->_perform_operation (
+		'Net::Amazon::S3::Operation::Buckets::List',
+	);
 
-    return unless $response->is_success;
+	return unless $response->is_success;
 
-    my $owner_id = $response->owner_id;
-    my $owner_display_name = $response->owner_displayname;
+	my $owner_id = $response->owner_id;
+	my $owner_display_name = $response->owner_displayname;
 
-    my @buckets;
-    foreach my $bucket ($response->buckets) {
-        push @buckets, $self->bucket_class->new (
+	my @buckets;
+	foreach my $bucket ($response->buckets) {
+		push @buckets, $self->bucket_class->new (
 			client             => $self,
 			name               => $bucket->{name},
 			creation_date      => $bucket->{creation_date},
@@ -69,58 +75,37 @@ sub buckets {
 			owner_display_name => $owner_display_name,
 		);
 
-    }
-    return @buckets;
+	}
+	return @buckets;
 }
 
 sub create_bucket {
-    my ( $self, %conf ) = @_;
+	my ( $self, %conf ) = @_;
 
-    my $bucket = $self->bucket_class->new(
-        client => $self,
-        name   => $conf{name},
-    );
-    $bucket->_create(%conf);
-    return $bucket;
+	my $bucket = $self->bucket_class->new(
+		client => $self,
+		name   => $conf{name},
+	);
+	$bucket->_create(%conf);
+	return $bucket;
 }
 
 sub bucket {
-    my ( $self, %conf ) = @_;
-    return $self->bucket_class->new(
-        client => $self,
-        %conf,
-    );
-}
-
-sub _send_request_raw {
-    my ( $self, $http_request, $filename ) = @_;
-
-	$http_request = $http_request->http_request
-		if $http_request->$Safe::Isa::_isa ('Net::Amazon::S3::Request');
-
-	return Net::Amazon::S3::Response->new (
-		http_response => scalar $self->s3->ua->request( $http_request, $filename ),
+	my ( $self, %conf ) = @_;
+	return $self->bucket_class->new(
+		client => $self,
+		%conf,
 	);
 }
 
-
 sub _perform_operation {
 	my ($self, $operation, %params) = @_;
 
-	my $error_handler = delete $params{error_handler};
-	$error_handler = $self->error_handler unless defined $error_handler;
-
-    my $request_class  = $operation . '::Request';
-    my $response_class = $operation . '::Response';
-    my $filename       = delete $params{filename};
-
-    my $request  = $request_class->new (s3 => $self->s3, %params);
-    my $response = $self->_send_request_raw ($request->http_request, $filename);
-    $response    = $response_class->new (http_response => $response->http_response);
-
-    $error_handler->handle_error ($response);
-
-    return $response;
+	return $self->s3->_perform_operation (
+		$operation,
+		error_handler => $self->error_handler,
+		%params
+	);
 }
 
 1;
@@ -137,7 +122,7 @@ Net::Amazon::S3::Client - An easy-to-use Amazon S3 client
 
 =head1 VERSION
 
-version 0.94
+version 0.95
 
 =head1 SYNOPSIS
 
@@ -187,20 +172,6 @@ to S3 and check the resultant ETag.
 WARNING: This is an early release of the Client classes, the APIs
 may change.
 
-=head2 _perform_operation
-
-Refer L<Net::Amazon::S3/_perform_operation
-
-Method supports additional parameters
-
-=over
-
-=item filename
-
-Filename callback (see L<LWP::UserAgent> for details) (optional)
-
-=back
-
 =for test_synopsis no strict 'vars'
 
 =head1 CONSTRUCTOR
